import { useState } from "react";

import { useTranslation } from "next-i18next";

import { Button, Grid, Space, useMantineTheme } from "@mantine/core";

import { Icon, ICONS } from "vseth-canine-ui";

import EventModal from "../components/eventModal";
import SignUpsModal from "../components/signUpsModal";
import EventCard from "../components/eventCard";
import { getAccentColor } from "../utilities/colors";

import { gql, useQuery } from "@apollo/client";

const getFutureEventsQuery = gql`
  query getFutureEvents {
    getFutureEvents {
      id
      title
      speaker
      description
      date
      startTime
      endTime
      place
      signUp
      isStammtisch
      signUps {
        sub
        firstName
        lastName
        email
      }
    }
  }
`;

export default function Events() {
  const { data: events, refetch } = useQuery(getFutureEventsQuery);
  const [open, setOpen] = useState(false);
  const [signUpOpen, setSignUpOpen] = useState(false);
  const [event, setEvent] = useState(null);

  const theme = useMantineTheme();
  const { t } = useTranslation("common");

  const addEvent = () => {
    setEvent(null);
    setOpen(true);
  };

  return (
    <>
      <h1>{t("events")}</h1>

      <Button
        leftIcon={<Icon icon={ICONS.PLUS} color={getAccentColor(theme)} />}
        onClick={addEvent}
        variant="default"
      >
        {t("addEvent")}
      </Button>

      <EventModal
        open={open}
        event={event}
        close={() => setOpen(false)}
        refetch={refetch}
      />
      <SignUpsModal
        open={signUpOpen}
        event={event}
        close={() => setSignUpOpen(false)}
      />

      <Space h="xl" />
      <Grid>
        {events &&
          events.getFutureEvents.map((e) => (
            <Grid.Col
              md={4}
              sm={6}
              xs={12}
              key={e.id}
              style={{ display: "flex" }}
            >
              <EventCard
                event={e}
                setEvent={setEvent}
                setOpen={setOpen}
                refetch={refetch}
                setSignUpOpen={setSignUpOpen}
              />
            </Grid.Col>
          ))}
      </Grid>
    </>
  );
}
